@@ -43,8 +43,8 @@
  * The fact that you are presently reading this means that you have had
  * knowledge of the CeCILL license and that you accept its terms.
  */
-#ifndef _TEXTPARAMETER_H_
-#define _TEXTPARAMETER_H_
+#ifndef ZART_TEXTPARAMETER_H
+#define ZART_TEXTPARAMETER_H
 
 #include <QDomNode>
 #include <QString>
@@ -55,14 +55,14 @@ class QLabel;
 class TextParameter : public AbstractParameter {
   Q_OBJECT
 public:
-  TextParameter(QDomNode node, QObject * parent = 0);
-  ~TextParameter();
-  void addTo(QWidget *, int row);
-  QString textValue() const;
-  QString unquotedTextValue() const;
-  void setValue(const QString & value);
-  void reset();
-  void saveValueInDOM();
+  TextParameter(QDomNode node, QObject * parent = nullptr);
+  ~TextParameter() override;
+  void addTo(QWidget *, int row) override;
+  QString textValue() const override;
+  QString unquotedTextValue() const override;
+  void setValue(const QString & value) override;
+  void reset() override;
+  void saveValueInDOM() override;
 public slots:
 signals:
   void valueChanged();
@@ -76,4 +76,4 @@ private:
   QLineEdit * _lineEdit;
 };
 
-#endif // _TEXTPARAMETER_H_
+#endif // ZART_TEXTPARAMETER_H
